@@ -10,11 +10,11 @@ use File::Which qw(which);
 use IPC::System::Options 'system', 'readpipe', -log=>1;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-25'; # DATE
+our $DATE = '2022-12-08'; # DATE
 our $DIST = 'Clipboard-Any'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
-my $known_clipboard_managers = [qw/klipper/];
+my $known_clipboard_managers = [qw/klipper parcellite/];
 my $sch_clipboard_manager = ['str', in=>$known_clipboard_managers];
 our %argspecopt_clipboard_manager = (
     clipboard_manager => {
@@ -37,9 +37,9 @@ $SPEC{':package'} = {
 
 This module provides common functions related to clipboard manager.
 
-Supported clipboard manager: KDE Plasma's Klipper (`klipper`). Support for more
-clipboard managers, e.g. on Windows or other Linux desktop environment is
-welcome.
+Supported clipboard manager: KDE Plasma's Klipper (`klipper`), `parcellite`.
+Support for more clipboard managers, e.g. on Windows or other Linux desktop
+environment is welcome.
 
 _
 };
@@ -61,10 +61,6 @@ _
 sub detect_clipboard_manager {
     my %args = @_;
 
-    #require Proc::Find;
-    #no warnings 'once';
-    #local $Proc::Find::CACHE = 1;
-
   KLIPPER:
     {
         log_trace "Checking whether clipboard manager klipper is running ...";
@@ -80,10 +76,39 @@ sub detect_clipboard_manager {
             log_trace "Failed listing org.kde.klipper /klipper methods, system is probably not using klipper";
             last;
         }
-        log_trace "Concluding klipper is active";
+        log_trace "org.kde.klipper/klipper object active, concluding using klipper";
         return "klipper";
     }
 
+    require Proc::Find;
+    no warnings 'once';
+    local $Proc::Find::CACHE = 1;
+
+  PARCELLITE:
+    {
+        log_trace "Checking whether clipboard manager parcellite is running ...";
+        my @pids = Proc::Find::find_proc(name => "parcellite");
+        if (@pids) {
+            log_trace "parcellite process is running, concluding using parcellite";
+            return "parcellite";
+        } else {
+            log_trace "parcellite process does not seem to be running, probably not using parcellite";
+        }
+    }
+
+  CLIPIT:
+    {
+        # basically the same as parcellite
+        log_trace "Checking whether clipboard manager clipit is running ...";
+        my @pids = Proc::Find::find_proc(name => "clipit");
+        if (@pids) {
+            log_trace "clipit process is running, concluding using clipit";
+            return "clipit";
+        } else {
+            log_trace "clipit process does not seem to be running, probably not using clipit";
+        }
+    }
+
     log_trace "No known clipboard manager is detected";
     undef;
 }
@@ -113,6 +138,10 @@ sub clear_clipboard_history {
         my $exit_code = $? < 0 ? $? : $?>>8;
         return [500, "/klipper's clearClipboardHistory failed: $exit_code"] if $exit_code;
         return [200, "OK"];
+    } elsif ($clipboard_manager eq 'parcellite') {
+        return [501, "Not yet implemented"];
+    } elsif ($clipboard_manager eq 'clipit') {
+        return [501, "Not yet implemented"];
     }
 
     [412, "Cannot clear clipboard history (clipboard manager=$clipboard_manager)"];
@@ -143,6 +172,10 @@ sub clear_clipboard_content {
         my $exit_code = $? < 0 ? $? : $?>>8;
         return [500, "/klipper's clearClipboardContents failed: $exit_code"] if $exit_code;
         return [200, "OK"];
+    } elsif ($clipboard_manager eq 'parcellite') {
+        return [501, "Not yet implemented"];
+    } elsif ($clipboard_manager eq 'clipit') {
+        return [501, "Not yet implemented"];
     }
 
     [412, "Cannot clear clipboard content (clipboard manager=$clipboard_manager)"];
@@ -186,6 +219,20 @@ sub get_clipboard_content {
         return [500, "/klipper's getClipboardContents failed: $exit_code"] if $exit_code;
         chomp $stdout;
         return [200, "OK", $stdout];
+    } elsif ($clipboard_manager eq 'parcellite') {
+        my ($stdout, $stderr);
+        system({capture_stdout=>\$stdout, capture_stderr=>\$stderr},
+               "parcellite", "-p");
+        my $exit_code = $? < 0 ? $? : $?>>8;
+        return [500, "parcellite command failed with exit code $exit_code"] if $exit_code;
+        return [200, "OK", $stdout];
+    } elsif ($clipboard_manager eq 'clipit') {
+        my ($stdout, $stderr);
+        system({capture_stdout=>\$stdout, capture_stderr=>\$stderr},
+               "clipit", "-p");
+        my $exit_code = $? < 0 ? $? : $?>>8;
+        return [500, "clipit command failed with exit code $exit_code"] if $exit_code;
+        return [200, "OK", $stdout];
     }
 
     [412, "Cannot get clipboard content (clipboard manager=$clipboard_manager)"];
@@ -243,6 +290,12 @@ sub list_clipboard_history {
             $i++;
         }
         return [200, "OK", \@rows];
+    } elsif ($clipboard_manager eq 'parcellite') {
+        # parcellite -c usually just prints the same result as -p (primary)
+        return [501, "Not yet implemented"];
+    } elsif ($clipboard_manager eq 'clipit') {
+        # clipit -c usually just prints the same result as -p (primary)
+        return [501, "Not yet implemented"];
     }
 
     [412, "Cannot list clipboard history (clipboard manager=$clipboard_manager)"];
@@ -286,6 +339,14 @@ sub add_clipboard_content {
         my $exit_code = $? < 0 ? $? : $?>>8;
         return [500, "/klipper's setClipboardContents failed: $exit_code"] if $exit_code;
         return [200, "OK"];
+    } elsif ($clipboard_manager eq 'parcellite') {
+        # parcellite cli copies unknown options and stdin to clipboard history
+        # but not as the current one
+        return [501, "Not yet implemented"];
+    } elsif ($clipboard_manager eq 'clipit') {
+        # clipit cli copies unknown options and stdin to clipboard history but
+        # not as the current one
+        return [501, "Not yet implemented"];
     }
 
     [412, "Cannot add clipboard content (clipboard manager=$clipboard_manager)"];
@@ -306,7 +367,7 @@ Clipboard::Any - Common interface to clipboard manager functions
 
 =head1 VERSION
 
-This document describes version 0.005 of Clipboard::Any (from Perl distribution Clipboard-Any), released on 2022-10-25.
+This document describes version 0.006 of Clipboard::Any (from Perl distribution Clipboard-Any), released on 2022-12-08.
 
 =head1 DESCRIPTION
 
@@ -333,9 +394,9 @@ on.
 
 This module provides common functions related to clipboard manager.
 
-Supported clipboard manager: KDE Plasma's Klipper (C<klipper>). Support for more
-clipboard managers, e.g. on Windows or other Linux desktop environment is
-welcome.
+Supported clipboard manager: KDE Plasma's Klipper (C<klipper>), C<parcellite>.
+Support for more clipboard managers, e.g. on Windows or other Linux desktop
+environment is welcome.
 
 =head1 NOTES
 
